@@ -285,6 +285,15 @@ class BaseBarHelper:
                 if trading_day == listing_date or HolidayHelper.is_post_holiday_trading_date(trading_day):
                     if dateTimeSlice.begin_time.hour > 6 and (dateTimeSlice.begin_time.hour < 18):  # 只有日盘
                         lst_all_date_time_slices.append([dateTimeSlice.begin_time, dateTimeSlice.end_time])
+                    elif dateTimeSlice.end_time.hour > 6 and (dateTimeSlice.end_time.hour < 18):
+                        for trading_time_slice in lst_trading_time_slices:
+                            pre_trading_day1 = TradingDayHelper.get_pre_trading_day(trading_day)
+                            pre_trading_day2 = pre_trading_day1 + datetime.timedelta(days=1)
+                            begin_time = YfTimeHelper.join_date_time(trading_day, pre_trading_day1, pre_trading_day2, trading_time_slice.begin_time)
+                            end_time = YfTimeHelper.join_date_time(trading_day, pre_trading_day1, pre_trading_day2, trading_time_slice.end_time)
+                            if begin_time.hour > 6 and (begin_time.hour < 10):
+                                dateTimeSlice.begin_time = begin_time
+                                lst_all_date_time_slices.append([dateTimeSlice.begin_time, dateTimeSlice.end_time])
                 else:
                     lst_all_date_time_slices.append([dateTimeSlice.begin_time, dateTimeSlice.end_time])
 
